@@ -6,7 +6,7 @@ logging.basicConfig(stream=sys.stdout, level=logging.INFO, format='%(asctime)s %
 import os
 import time
 import tqdm
-from .util import _get_kmer_index_from_args, get_kmer_hashes_from_chunk_sequence, open_file
+from .util import _get_kmer_index_from_args, get_kmer_hashes_from_chunk_sequence, open_file, log_memory_usage_now
 import numpy as np
 import warnings
 warnings.filterwarnings("ignore", category=np.VisibleDeprecationWarning) 
@@ -37,6 +37,8 @@ def map_cpu(args, kmer_index, chunk_sequence_name):
     chunk_sequence = object_from_shared_memory(chunk_sequence_name).get_data().sequence
     logging.debug("N sequences in chunk: %d" % len(chunk_sequence))
     hashes = get_kmer_hashes_from_chunk_sequence(chunk_sequence, kmer_size)
+    logging.debug("Removing %s" % chunk_sequence_name)
+    remove_shared_memory(chunk_sequence_name)  # removev now to save some memory usage
 
     t0 = time.perf_counter()
     if isinstance(kmer_index, CounterKmerIndex):
@@ -48,7 +50,6 @@ def map_cpu(args, kmer_index, chunk_sequence_name):
 
     logging.debug("Mapping %d hashes took %.3f sec" % (len(hashes), time.perf_counter()-t0))
 
-    remove_shared_memory(chunk_sequence_name)
     logging.debug("Chunk of %d reads took %.2f sec" % (len(chunk_sequence), time.perf_counter()-t))
     return mapped
 
@@ -65,11 +66,11 @@ def map_gpu(index, chunks, k, map_reverse_complements=False):
     for i, chunk in enumerate(chunks):
         t0 = time.perf_counter()
         hashes = get_kmer_hashes_from_chunk_sequence(chunk.get_data().sequence, k)
-        logging.info("Time to get hashes for chunk ", (time.perf_counter()-t0))
+        logging.info("Time to get hashes for chunk: %.5f", (time.perf_counter()-t0))
         t1 = time.perf_counter()
         counter.count(hashes, count_revcomps=map_reverse_complements)
         logging.info("Time to count %d hashes for chunk: %.10f" % (len(hashes), time.perf_counter()-t1))
-        logging.info("GPU: Whole chunk finished in ", (time.perf_counter()-t0))
+        logging.info("GPU: Whole chunk finished in %.5f sec", (time.perf_counter()-t0))
 
     logging.info("Time spent only on hashing and counting hashes: %.5f" % (time.perf_counter()-t_start))
     return counter.get_node_counts(min_nodes=index.max_node_id())
@@ -101,7 +102,7 @@ def map_bnp(args):
         chunks = tqdm.tqdm(chunks, total=approx_number_of_chunks)
 
         if isinstance(kmer_index, KmerIndex):
-            initial_data = np.zeros(kmer_index.max_node_id()+1)
+            initial_data = np.zeros(kmer_index.max_node_id()+1, dtype=np.uint32)
         else:
             initial_data = np.zeros_like(kmer_index.counter._values)
 
@@ -123,6 +124,8 @@ def map_bnp(args):
             node_counts = kmer_index.get_node_counts()
             logging.info("Time spent getting node counts in the end: %.3f" % (time.perf_counter()-t))
 
+    if args.output_file is None:
+        return node_counts
 
     np.save(args.output_file, node_counts)
     logging.info("Saved node counts to %s.npy" % args.output_file)
@@ -144,7 +147,7 @@ def run_argument_parser(args):
     subparser.add_argument("-f", "--reads", required=True, help="Reads in .fa, .fq, .fa.gz, or fq.gz format")
     subparser.add_argument("-k", "--kmer-size", required=False, default=31, type=int)
     subparser.add_argument("-t", "--n-threads", required=False, default=16, type=int)
-    subparser.add_argument("-c", "--chunk-size", required=False, type=int, default=100000000,
+    subparser.add_argument("-c", "--chunk-size", required=False, type=int, default=2500000,
                            help="N bytes to process in each chunk")
     subparser.add_argument("-o", "--output-file", required=True)
     subparser.add_argument("-d", "--debug", required=False, help="Set to True to print debug log")
